use eframe::{
    egui::{Color32, Ui},
    epaint::CircleShape,
};
use egui_plot::PlotUi;

use crate::{
    application::Application,
    geometry::{elements::Element, DrawableRaw},
};

use super::{draw_floating_area_on_canvas, draw_on_plot_canvas, CanvasColour, Drawer, PlotDrawer};

pub fn draw_excellons_(ui: &mut PlotUi, app: &mut Application) {
    for (file_name, (_, excellon)) in &app.excellons {
        let selected = &app.selection == file_name;

        for circle in excellon.holes.iter() {
            draw_on_plot_canvas(
                ui,
                app,
                PlotDrawer::Drawable((
                    &Element::Circle(circle.to_owned()),
                    CanvasColour::Excellon,
                    selected,
                )),
            );
        }
    }
}

pub fn draw_excellons(ui: &mut Ui, app: &mut Application) {
    for (file_name, (ex_name, excellon)) in &app.excellons {
        let selected = &app.selection == file_name;

        for (i, circle) in excellon.holes.iter().enumerate() {
            draw_floating_area_on_canvas(
                ui,
                app,
                circle.canvas_pos(),
                ("ExcellonArea", ex_name, i),
                Drawer::Closure(&|ui| {
                    ui.painter().add(CircleShape::filled(
                        circle.position.invert_y().into(),
                        circle.diameter as f32 / 2.,
                        if selected {
                            Color32::BROWN.gamma_multiply(0.5)
                        } else {
                            Color32::BROWN
                        },
                    ));
                }),
            );
        }
    }
}
