use eframe::egui::{self, Color32, Pos2, TextWrapMode, Ui, Vec2};

use crate::application::Application;

pub fn draw_live_position(ui: &mut Ui, app: &mut Application) {
    if let Some(cursor) = cursor_canvas_position(app, ui) {
        let _id = egui::Area::new(app.canvas.0.with("cursor_position_box"))
            .fixed_pos(app.canvas.1.min)
            // .order(egui::Order::Middle)
            .default_size(Vec2::new(80., 80.))
            .show(ui.ctx(), |ui| {
                // let painter = ui.painter();
                // painter.add(RectShape::filled(Rect::from_min_size(rect.min, Vec2::new(80., 80.)), Rounding::ZERO, Color32::LIGHT_BLUE));
                egui::Frame::default()
                    .rounding(egui::Rounding::same(4.0))
                    .inner_margin(egui::Margin::same(8.0))
                    .stroke(ui.ctx().style().visuals.window_stroke)
                    .fill(Color32::from_rgba_premultiplied(0xAD, 0xD8, 0xE6, 200))
                    .show(ui, |ui| {
                        ui.style_mut().wrap_mode = Some(TextWrapMode::Extend);
                        let cursor_position = app.transform.inverse() * cursor; // + rect.min.to_vec2() - app.canvas_size.min;
                        let cursor_position2 = app.test_transform.inverse() * cursor; // + rect.min.to_vec2() - app.canvas_size.min;

                        ui.label(format!(
                            "x: {} {}",
                            (-app.transform.translation.x + cursor.x) / app.transform.scaling,
                            app.variables.units
                        ));
                        ui.label(format!(
                            "y: {} {}",
                            // cursor.y / app.transform.scaling + app.test_transform.translation.y,
                            (-app.transform.translation.y + cursor.y) / app.transform.scaling,
                            app.variables.units
                        ));
                        ui.label(format!(
                            "cursor: {:?} {}",
                            cursor_position, app.variables.units
                        ));
                        ui.label(format!(
                            "cursor2: {:?} {}",
                            cursor_position2, app.variables.units
                        ));

                        ui.label(format!("{:?} - {:?}", app.transform, app.test_transform))
                    });
            });
    }
}

fn cursor_canvas_position(app: &Application, ui: &mut Ui) -> Option<Pos2> {
    let pointer_pos = ui.ctx().input(|i| i.pointer.hover_pos());

    if let Some(cursor) = pointer_pos {
        let pos = cursor - app.canvas.1.min;
        match (pos.x, pos.y) {
            (x, y) if x > 0. && y > 0. => Some(pos.to_pos2()),
            (_, _) => None,
        }
    } else {
        None
    }
    // pointer_pos.map(|pos| (pos - app.canvas_size.min).to_pos2())
}
