mod canvas;
mod egui;
pub mod panels;

use std::collections::HashMap;

use eframe::{
    egui::{Id, Pos2, Rect, Vec2},
    emath::TSTransform,
};

use crate::{
    excellon::drills::Drills,
    geometry::{Geometry, Unit},
    outline_geometry::OutlineGeometry,
};

pub use canvas::CanvasColour;

pub struct Application {
    gerbers: HashMap<String, (String, Geometry)>,
    outlines: HashMap<String, OutlineGeometry>,
    excellons: HashMap<String, (String, Drills)>,
    // geometry: Geometry,
    transform: TSTransform,
    test_transform: TSTransform,
    canvas: (Id, Rect),
    selection: String,
    variables: Variables,
}

#[derive(Debug, Default)]
pub struct Variables {
    laser_line_width: f32,
    units: Unit,
}

impl Application {
    pub fn new() -> Self {
        Self {
            gerbers: HashMap::new(),
            outlines: HashMap::new(),
            excellons: HashMap::new(),
            // geometry,
            transform: TSTransform::default(),
            test_transform: TSTransform::default(),
            canvas: (
                Id::new("0"),
                Rect::from_center_size(Pos2::new(0., 0.), Vec2::default()),
            ),
            selection: "".into(),
            variables: Variables::default(),
        }
    }
}
