use eframe::egui::Ui;

use crate::{
    application::Application,
    geometry::{ClipperPath, ClipperPaths, DrawableRaw},
    outline_geometry::OutlineGeometry,
};

use super::HOLE_MARK_DIAMETER;

pub fn show_excellon_actions(ui: &mut Ui, app: &mut Application) {
    if let Some((name, drill)) = app.excellons.get(&app.selection) {
        if ui.button("Generate cut out").clicked() {
            let path = drill
                .holes
                .iter()
                .map(|hole| hole.outline.clone())
                .collect::<Vec<ClipperPath>>()
                .into();
            app.outlines.insert(
                format!("{name}-CutOut"),
                OutlineGeometry::new_no_inflate(
                    &path,
                    0.1,
                    app.variables.units,
                    name,
                    path.bounds(),
                ),
            );
        }
        if ui.button("Generate hole mark").clicked() {
            app.outlines.insert(
                format!("{name}-HoleMark"),
                OutlineGeometry::point_marker(
                    drill.holes.iter().map(|c| c.canvas_pos()).collect(),
                    HOLE_MARK_DIAMETER,
                    app.variables.units,
                    name,
                    ClipperPaths::from(
                        drill
                            .holes
                            .iter()
                            .map(|hole| hole.outline.clone())
                            .collect::<Vec<ClipperPath>>(),
                    )
                    .bounds(),
                ),
            );
        }
    }
}
