use eframe::egui::{ComboBox, Ui};

use crate::{application::Application, export::svg::SVGConverter};

pub fn show_geometry_actions(ui: &mut Ui, app: &mut Application) {
    if let Some(outline) = app.outlines.get_mut(&app.selection) {
        ui.label("BoundingBox");
        ComboBox::from_label("Select one!")
            .selected_text(format!("{:?}", outline.bounds_from))
            .show_ui(ui, |ui| {
                for (key, (name, _)) in app.gerbers.iter() {
                    if ui
                        .selectable_value(&mut outline.bounds_from, name.into(), name)
                        .clicked()
                    {
                        if let Some((_, box_geo)) = app.gerbers.get(key) {
                            outline.bounding_box = box_geo.outline_union.bounds();
                        }
                    }
                }
            });

        if ui.button("Save as SVG").clicked() {
            if let Some(path) = rfd::FileDialog::new()
                .set_title("Save as SVG")
                .set_file_name(app.selection.to_string())
                .add_filter("SVG", &["svg", "SVG"])
                .save_file()
            {
                SVGConverter::export(outline, &path);
            }
        }
    }
}
