use std::{fs::File, io::BufReader};

use eframe::egui;

use crate::{
    application::Application,
    excellon::{drills::Drills, parse_excellon},
    geometry::Geometry,
    gerber::parse_gerber,
};

pub fn draw_header(ctx: &egui::Context, app: &mut Application) {
    egui::TopBottomPanel::top("top_panel")
        .exact_height(40.)
        .show(ctx, |ui| {
            ui.horizontal(|ui| {
                if ui.button("Open Gerber").clicked() {
                    if let Some(paths) = rfd::FileDialog::new()
                        .add_filter("Gerber", &["GBR ", "gbr", "GB", "geb"])
                        .pick_files()
                    {
                        // self.picked_path = Some(path.display().to_string());
                        for path in paths {
                            // TODO remove all unwraps
                            if let Ok(file) = File::open(&path) {
                                let gerber = parse_gerber(BufReader::new(file));
                                let name = path.file_name().unwrap().to_str().unwrap().to_string();
                                app.gerbers.insert(
                                    path.to_str().unwrap().into(),
                                    (name, Geometry::from(gerber).to_unit(app.variables.units)),
                                );
                            } else {
                                // TODO show error
                            };
                        }
                    }
                }

                if ui.button("Open Excellon").clicked() {
                    if let Some(paths) = rfd::FileDialog::new()
                        .add_filter("Excellon", &["DRL ", "drl"])
                        .pick_files()
                    {
                        for path in paths {
                            // TODO remove all unwraps
                            if let Ok(file) = File::open(&path) {
                                let excellon = parse_excellon(BufReader::new(file)).unwrap();
                                let drills: Drills = excellon.into();
                                let name = path.file_name().unwrap().to_str().unwrap().to_string();
                                app.excellons.insert(
                                    path.to_str().unwrap().into(),
                                    (name, drills.to_unit(app.variables.units)),
                                );
                            } else {
                                // TODO show error
                            };
                        }
                    }
                }
            })
        });
}
