#![cfg_attr(not(debug_assertions), windows_subsystem = "windows")] // hide console window on Windows in release

mod application;
mod excellon;
mod export;
mod geometry;
mod gerber;
mod outline_geometry;

use application::Application;

use eframe::egui;
use tracing_subscriber::{filter, layer::SubscriberExt, util::SubscriberInitExt, Layer};

const APP_NAME: &str = "Outlinify";

fn main() -> eframe::Result {
    let stdout_log = tracing_subscriber::fmt::layer()
        .pretty()
        .with_filter(filter::filter_fn(|metadata| {
            metadata.target().starts_with(env!("CARGO_CRATE_NAME"))
        }))
        .with_filter(filter::LevelFilter::DEBUG);

    // Register subscriptions
    tracing_subscriber::registry().with(stdout_log).init();

    let application = Application::new();

    let options = eframe::NativeOptions {
        viewport: egui::ViewportBuilder::default().with_inner_size([900.0, 700.0]),
        ..Default::default()
    };
    eframe::run_native(
        APP_NAME,
        options,
        Box::new(|cc| {
            // This gives us image support:
            // egui_extras::install_image_loaders(&cc.egui_ctx);

            Ok(Box::new(application))
        }),
    )
}
